#
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

from __future__ import print_function
import sys
from pyspark.sql import SparkSession



if __name__ == "__main__":
    if len(sys.argv) != 3:
        print("Error: Expecting 3 arguments {} provided".format(len(sys.argv) - 1), file=sys.stderr)
        print("Usage: transform_to_parquet.py  <Input S3 Path> <Output S3 Path>", file=sys.stderr)
        sys.exit(1)
    input_path = sys.argv[1]
    output_path = sys.argv[2]
    #warehouse_location = abspath('spark-warehouse')

    spark = SparkSession \
        .builder \
        .appName("Transform to Parquet - Demo code only") \
        .getOrCreate()

    # Spark is an existing SparkSession
    input_df = spark.read.format("csv").option("header", "true").option("inferschema", "true").load(input_path)

    input_df.write.mode("overwrite").parquet(output_path)

    spark.stop()
