#!/bin/bash -x
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -o errexit -o nounset -o pipefail

APP_ID=hadoop-2.8.5
APP_NAME=hadoop-2.8.5
export HADOOP_DEPENDENCIES_DIR=${GENIE_APPLICATION_DIR}/${APP_ID}/dependencies
export HADOOP_HOME=${HADOOP_DEPENDENCIES_DIR}/${APP_NAME}

tar -xf ${HADOOP_DEPENDENCIES_DIR}/${APP_NAME}.tar.gz -C ${HADOOP_DEPENDENCIES_DIR}

# Sync AWS EMR libs
AWS_DIR=${HADOOP_DEPENDENCIES_DIR}/aws
aws s3 sync s3://${S3_BUCKET}/genie/clusters/${GENIE_CLUSTER_ID}/aws/ ${AWS_DIR}/ --region $AWS_REGION
aws s3 sync s3://${S3_BUCKET}/genie/clusters/${GENIE_CLUSTER_ID}/rpm/ ${HADOOP_DEPENDENCIES_DIR}/rpm/ --region $AWS_REGION

# Install LZO rpm
sudo /usr/bin/yum -y localinstall ${HADOOP_DEPENDENCIES_DIR}/rpm/hadoop-lzo-0.4.19-1.amzn1.x86_64.rpm
# Export Hadoop environment
export HADOOP_CONF_DIR="${HADOOP_HOME}/etc/hadoop"
export HADOOP_LIBEXEC_DIR="${HADOOP_HOME}/libexec"
export LD_LIBRARY_PATH="${HADOOP_HOME}/lib/native:/usr/lib/hadoop-lzo/lib/native"

# AWS configurations
export JAVA_LIBRARY_PATH="/usr/lib/hadoop-lzo/lib/native"
export HADOOP_CLASSPATH="/usr/lib/hadoop-lzo/lib/*"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/aws-java-sdk/*"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/emrfs/conf"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/emrfs/lib/*"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/emrfs/auxlib/*"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/ddb/lib/emr-ddb-hadoop.jar"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/goodies/lib/emr-hadoop-goodies.jar"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/kinesis/lib/emr-kinesis-hadoop.jar"
export HADOOP_CLASSPATH="$HADOOP_CLASSPATH:${AWS_DIR}/emr/s3-dist-cp/lib/*"

/bin/cp --force ${GENIE_CLUSTER_DIR}/config/* ${HADOOP_CONF_DIR}/

# Remove the zip to save space
rm ${HADOOP_DEPENDENCIES_DIR}/${APP_NAME}.tar.gz

