#!/bin/bash -x
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

set -o errexit -o nounset -o pipefail 
 
start_dir=`pwd` 
cd `dirname ${BASH_SOURCE[0]}` 
SPARK_BASE=`pwd` 
cd $start_dir 
 
export SPARK_DAEMON_JAVA_OPTS="-verbose:gc -XX:+PrintGCDetails -XX:+PrintGCTimeStamps" 
export SPARK_DEPS=${SPARK_BASE}/dependencies 
export SPARK_VERSION="2.4.3" 

tar xzf ${SPARK_DEPS}/spark-${SPARK_VERSION}-bin-hadoop2.7.tgz -C ${SPARK_DEPS} 

# Set the required environment variables: spark-env.sh
export SPARK_HOME=${SPARK_DEPS}/spark-${SPARK_VERSION}-bin-hadoop2.7 
export SPARK_CONF_DIR=${SPARK_HOME}/conf 
export SPARK_LOG_DIR=${GENIE_JOB_DIR} 
export SPARK_LOG_FILE=spark.log 
export SPARK_LOG_FILE_PATH=${GENIE_JOB_DIR}/${SPARK_LOG_FILE} 
export CURRENT_JOB_WORKING_DIR=${GENIE_JOB_DIR} 
export CURRENT_JOB_TMP_DIR=${CURRENT_JOB_WORKING_DIR}/tmp

# Make Sure Script is on the Path 
export PATH=$PATH:${SPARK_HOME}/bin
# Get EMR hive-site.xml
HIVE_SITE=""
aws s3 cp s3://${S3_BUCKET}/genie/clusters/${GENIE_CLUSTER_ID}/conf/spark/hive-site.xml ${SPARK_CONF_DIR}/hive-site.xml --region $AWS_REGION && HIVE_SITE=${SPARK_CONF_DIR}/hive-site.xml

# Export PYTHONPATH for Genie
export PYTHONPATH="${SPARK_HOME}/python:${SPARK_HOME}/python/lib/pyspark.zip:${SPARK_HOME}/python/lib/py4j-0.10.4-src.zip"

#EMRFS goodies from EMR Version that runs Hadoop 2.7.3 (emr-5.11.3)
aws s3 sync s3://${S3_BUCKET}/genie/applications/spark-${SPARK_VERSION}/hadoop-2.7/aws/emr/emrfs/ ${HADOOP_DEPENDENCIES_DIR}/aws/emr/emrfs/

# Create spark defaults file
AWS_DEPENDENCIES_DIR=${HADOOP_DEPENDENCIES_DIR}/aws
cat > ${SPARK_CONF_DIR}/spark-defaults.conf <<EOF
spark.driver.extraClassPath      :/usr/lib/hadoop-lzo/lib/*:${HADOOP_HOME}/share/hadoop/tools/lib/hadoop-aws.jar:${AWS_DEPENDENCIES_DIR}/aws-java-sdk/*:${AWS_DEPENDENCIES_DIR}/emr/emrfs/conf:${AWS_DEPENDENCIES_DIR}/emr/emrfs/lib/*:${AWS_DEPENDENCIES_DIR}/emr/emrfs/auxlib/*:${AWS_DEPENDENCIES_DIR}/emr/s3-dist-cp/lib/*
spark.driver.extraLibraryPath    ${HADOOP_HOME}/lib/native:/usr/lib/hadoop-lzo/lib/native
spark.executor.extraClassPath    :/usr/lib/hadoop-lzo/lib/*:/usr/lib/hadoop/hadoop-aws.jar:/usr/share/aws/aws-java-sdk/*:/usr/share/aws/emr/emrfs/conf:/usr/share/aws/emr/emrfs/lib/*:/usr/share/aws/emr/emrfs/auxlib/*:/usr/share/aws/emr/security/conf:/usr/share/aws/emr/security/lib/*
spark.executor.extraLibraryPath  ${HADOOP_HOME}/lib/native:/usr/lib/hadoop-lzo/lib/native
spark.eventLog.enabled           true
spark.eventLog.dir               hdfs:///var/log/spark/apps
spark.history.fs.logDirectory    hdfs:///var/log/spark/apps
spark.sql.warehouse.dir          hdfs:///user/spark/warehouse
spark.yarn.historyServer.address \${hadoopconf-yarn.resourcemanager.hostname}:18080
spark.history.ui.port            18080
spark.shuffle.service.enabled    true
spark.yarn.dist.files            ${HIVE_SITE}
spark.dynamicAllocation.enabled  true
spark.hadoop.yarn.timeline-service.enabled false
#spark.driver.extraJavaOptions    -XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=70 -XX:MaxHeapFreeRatio=70 -XX:+CMSClassUnloadingEnabled -XX:OnOutOfMemoryError='kill -9 %p'
#spark.executor.extraJavaOptions  -verbose:gc -XX:+PrintGCDetails -XX:+PrintGCDateStamps -XX:+UseConcMarkSweepGC -XX:CMSInitiatingOccupancyFraction=70 -XX:MaxHeapFreeRatio=70 -XX:+CMSClassUnloadingEnabled -XX:OnOutOfMemoryError='kill -9 %p'
#spark.executor.memory            5120M
#spark.executor.cores             4
EOF

# Delete the tarball to save space 
rm ${SPARK_DEPS}/spark-${SPARK_VERSION}-bin-hadoop2.7.tgz
