#!/bin/bash -x
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
##### 
# Run this as an EMR Step to register cluster with Genie.
# The script will also upload all EMR libraries on S3
# Each application must have a YAML config in s3://${S3_BUCKET}/genie/applications/${APP_NAME}-${APP_VERSION}.yml
# e.g. for sqoop s3://mybucket/genie/artifacts/genie_register_spark-2.1.0.py
# application name must match EMR naming under /etc/ directory
# application version must be the same or compatible with the EMR version
#
#Creates a yaml file that represents a Genie Application Resource.

if [ "$#" -ne 8 ]
then
	echo -e "Usage: $0 genie_s3_bucket_name app_id app_name app_version app_type binary app_description AWS_region \n"
	echo -e "  Example:"
	echo -e "  $0 mybucket hadoop-2.8.5 hadoop 2.8.5 hadoop hadoop-2.8.5.tar.gz 'Hadoop 2.8.5 Application' us-east-2" 
	echo -e "  $0 mybucket spark-2.4.3 spark 2.4.3 spark spark-2.4.3-bin-hadoop2.7.tgz 'Spark 2.4.3 Application' us-east-2" 
	exit 1
fi

export GENIE_S3_BUCKET_LOCATION=$1
export APP_ID=$2
export APP_NAME=$3
export APP_VERSION=$4
export APP_TYPE=$5
export APP_BINARY=$6
export APP_DESCRIPTION=$7
export AWS_REGION=$8
echo "Generating Application Resource file"

YAML_FILE="${APP_ID}.yml"
cat > ./${YAML_FILE} <<EOF
id: ${APP_ID}
name: ${APP_NAME}
user: hadoop
status: ACTIVE
description: ${7}
setupFile: s3://${GENIE_S3_BUCKET_LOCATION}/genie/applications/${APP_ID}/setup.sh
configs: []
version: ${APP_VERSION}
type: ${APP_TYPE}
tags:
  - type:${APP_TYPE}
  - version:${APP_VERSION}
dependencies:
  - s3://${GENIE_S3_BUCKET_LOCATION}/genie/applications/${APP_ID}/${APP_BINARY}
EOF

/usr/bin/aws s3 cp ${YAML_FILE} s3://${GENIE_S3_BUCKET_LOCATION}/genie/applications/${APP_ID}/  --region ${AWS_REGION}
