#!/bin/bash -x
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
##### 
# Run this as an EMR Step to register cluster with Genie.
# The script will also upload all EMR libraries on S3
# Each application must have a YAML config in s3://${S3_BUCKET}/genie/applications/${APP_NAME}-${APP_VERSION}.yml
# e.g. for sqoop s3://mybucket/genie/artifacts/genie_register_spark-2.1.0.py
# application name must match EMR naming under /etc/ directory
# application version must be the same or compatible with the EMR version
#
#Creates the yaml files that represent a Genie command resource.

if [ "$#" -ne 7 ]
then
	echo -e "Usage: $0 genie_s3_bucket_name command_id command_name command_version command_type command_description AWS_Region \n"
	echo -e "  Example:"
	echo -e "  $0 mybucket spark-2.4.3_spark-submit 'Spark Submit' 2.4.3 spark-submit 'Spark Submit Command' us-east-2" 
	exit 1
fi

export GENIE_S3_BUCKET_LOCATION=$1
export COMMAND_ID=$2
export COMMAND_NAME=$3
export COMMAND_VERSION=$4
export COMMAND_TYPE=$5
export COMMAND_DESCRIPTION=$6
export AWS_REGION=$7

echo "Generating a Command Resource file"

YAML_FILE="${COMMAND_ID}.yml"
cat > ./${YAML_FILE} <<EOF
id: ${COMMAND_ID}
name: ${COMMAND_NAME}
user: hadoop
status: ACTIVE
description: ${COMMAND_DESCRIPTION} 
setupFile: s3://${GENIE_S3_BUCKET_LOCATION}/genie/commands/${COMMAND_ID}/setup.sh
configs: []
executable: \${SPARK_HOME}/bin/spark-submit --master yarn --deploy-mode client 
version: ${COMMAND_VERSION}
tags:
  - type:${COMMAND_TYPE}
  - version:${COMMAND_VERSION}
checkDelay: 5000
EOF

/usr/bin/aws s3 cp ${YAML_FILE} s3://${GENIE_S3_BUCKET_LOCATION}/genie/commands/${COMMAND_ID}/  --region ${AWS_REGION}
