#!/bin/bash -x
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

# Run this as an EMR Step to extract EMRFSA binary.

if [ "$#" -ne 1 ]
then
	echo -e "Usage: $0 s3_bucket_name \n"
	echo -e "  Example:"
	echo -e "  $0 mybucket " 
	exit 1
fi

IS_MASTER=$(jq -r '.isMaster' /mnt/var/lib/info/instance.json)
if [ "${IS_MASTER}" != "true" ]
then
	echo "Hostname $(hostname) is not a master ... exiting"
	exit 0
fi

# Grab command line parameters
# e.g. mybucket
S3_BUCKET=$1 

REGION=$(curl -s http://169.254.169.254/latest/meta-data/placement/availability-zone/|sed 's/.$//')

aws s3 cp --region ${REGION}  /usr/share/aws/emr/emrfs/lib/emrfs-hadoop-assembly-2.20.0.jar s3://${S3_BUCKET}/genie/applications/spark-2.4.3/hadoop-2.7/aws/emr/emrfs/lib/

exit 0
