#!/usr/bin/python2.7
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

'''
Details: Links Registered Command Resources with Registered Clusters.
Usage:
  python genie_link_command_to_clusters.py bucket-name-with-Genie-artifacts aws-region http://URL-of-the-Genie-Server:8080
'''  

import logging
import sys
import yaml
import pygenie
from pygenie.client import Genie
from pygenie.conf import GenieConf
import boto3
import botocore

logging.basicConfig(level=logging.INFO)
LOGGER = logging.getLogger(__name__)

# Change cluster_name below
clusters = [{'cluster_name' : 'j-xxxxxxxx', 'commands' : ['spark-2.4.3_spark-submit']}]
           

def load_from_s3(client, bucket_name, s3_object_key, aws_region):
    s3_object = s3.get_object(Bucket=bucket_name, Key=s3_object_key)
    contents = s3_object['Body'].read()
    return contents


def load_yaml_from_file(yaml_file):
    with open(yaml_file) as _file:
        return yaml.load(_file)


if __name__ == "__main__":
    (s3_bucket, aws_region, genie_endpoint) = sys.argv[1:]

    genie_conf = GenieConf()
    genie_conf.genie.url = genie_endpoint
    genie = Genie(genie_conf)
    s3 = boto3.client("s3", region_name=aws_region)   

    #Link a command to a specific cluster. After linking, the cluster can run the command.
    for cluster_mapping in clusters:      
        cluster_id = cluster_mapping["cluster_name"]
        command_ids = cluster_mapping["commands"]
        try: 
            genie.set_commands_for_cluster(cluster_id, command_ids)
            LOGGER.info("Set commands: {commands} for cluster: {cluster_id}".format(commands=','.join(command_ids), cluster_id=cluster_id))
        except Exception:
            LOGGER.info("Commands: {commands} for cluster: {cluster_id} already registered".format(commands=','.join(command_ids), cluster_id=cluster_id))
