#!/usr/bin/python2.7
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
'''
Details: Register Application Resources With Genie
Usage:
  python genie_register_application_resources.py bucket-name-with-Genie-artifacts aws-region http://URL-of-the-Genie-Server:8080
'''
import logging
import sys
import yaml
import pygenie
from pygenie.client import Genie
from pygenie.conf import GenieConf
import boto3
import botocore

logging.basicConfig(level=logging.INFO)
LOGGER = logging.getLogger(__name__)

applications = ['hadoop-2.8.5',
                'spark-2.4.3']

def load_from_s3(client, bucket_name, s3_object_key, aws_region):
    s3_object = s3.get_object(Bucket=bucket_name, Key=s3_object_key)
    contents = s3_object['Body'].read()
    return contents


def load_yaml_from_file(yaml_file):
    with open(yaml_file) as _file:
        return yaml.load(_file)


if __name__ == "__main__":
    (s3_bucket, aws_region, genie_endpoint) = sys.argv[1:]

    genie_conf = GenieConf()
    genie_conf.genie.url = genie_endpoint
    genie = Genie(genie_conf)
    s3 = boto3.client("s3", region_name=aws_region)   

    # Register applications
    application_ids = {}
    for application_name in applications:
        s3_app_key = "genie/applications/{application_name}/{application_name}.yml".format(application_name=application_name)
        try:
            app_conf_yaml = load_from_s3(s3, s3_bucket, s3_app_key, aws_region)
        except botocore.exceptions.ClientError:
            LOGGER.warn("YAML configuration file not found for EMR application: {application_name}; Skipping...".format(application_name=application_name))
            continue
        
        application = yaml.load(app_conf_yaml)
        try:
            application_id = genie.create_application(application)
            LOGGER.info("Created application: {application_name} with id:{application_id}".format(application_name=application_name, application_id=application_id))
        except pygenie.exceptions.GenieHTTPError:
            LOGGER.warn("Application: {application_name} exists. Updating in Genie...".format(application_name=application_name))
            genie.update_application(application)
            application_id = application["id"]
        application_ids[application_name] = application_id
