#!/usr/bin/python2.7
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
# Genie API: https://github.com/Netflix/genie/blob/8c01cb1c7c8ba69d585fcd740cc0ec9c34b05162/genie-client/src/main/python/pygenie/client.py

import logging
import sys
import yaml
from pygenie.client import Genie
from pygenie.conf import GenieConf
import pygenie
import boto3

logging.basicConfig(level=logging.INFO)
LOGGER = logging.getLogger(__name__)

if __name__ == "__main__":
    (cluster_yaml_file, s3_bucket, aws_region, genie_endpoint) = sys.argv[1:]
    
    genie_conf = GenieConf()
    genie_conf.genie.url = genie_endpoint
    genie = Genie(genie_conf)
    s3 = boto3.client("s3", region_name=aws_region)   
     
    with open(cluster_yaml_file) as foo:
        cluster = yaml.load(foo)

    cluster_id = cluster["id"]                        
    try:
        genie.create_cluster(cluster)
        LOGGER.info("Created cluster: {cluster_id}".format(cluster_id=cluster_id))
    except pygenie.exceptions.GenieHTTPError:
                LOGGER.warn("Cluster: {cluster} exists. Updating in Genie...".format(cluster=cluster_id))
                genie.update_cluster(cluster_id, cluster)
