#!/usr/bin/python2.7
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#

'''
Details: Register Command Resources with Genie
Usage:
  python genie_register_command_resources_and_associate_applications.py bucket-name-with-Genie-artifacts aws-region http://URL-of-the-Genie-Server:8080
'''  

import logging
import sys
import yaml
import pygenie
from pygenie.client import Genie
from pygenie.conf import GenieConf
import boto3
import botocore

logging.basicConfig(level=logging.INFO)
LOGGER = logging.getLogger(__name__)

commands = [{'command_name' : 'spark-2.4.3_spark-submit', 'applications' : ['hadoop-2.8.5', 'spark-2.4.3']}]
#Map between Application name and Application IDs as seen by Genie. 
application_ids={'spark-2.4.3': 'spark-2.4.3', 'hadoop-2.8.5': 'hadoop-2.8.5'}

def load_from_s3(client, bucket_name, s3_object_key, aws_region):
    s3_object = s3.get_object(Bucket=bucket_name, Key=s3_object_key)
    contents = s3_object['Body'].read()
    return contents


def load_yaml_from_file(yaml_file):
    with open(yaml_file) as _file:
        return yaml.load(_file)


if __name__ == "__main__":
    (s3_bucket, aws_region, genie_endpoint) = sys.argv[1:]

    genie_conf = GenieConf()
    genie_conf.genie.url = genie_endpoint
    genie = Genie(genie_conf)
    s3 = boto3.client("s3", region_name=aws_region)   
   
    #register commands 
    for command_mapping in commands:
        s3_command_key = "genie/commands/{command_name}/{command_name}.yml".format(command_name=command_mapping['command_name'])
        try:
            command_conf_yaml = load_from_s3(s3, s3_bucket, s3_command_key, aws_region)
        except botocore.exceptions.ClientError:
            LOGGER.warn("YAML configuration file not found for EMR command: {command_name}; Skipping...".format(command_name=command_mapping['command_name']))
            continue

        command = yaml.load(command_conf_yaml)
        try:
            command_id = genie.create_command(command)
            LOGGER.info("Created Hadoop command with id: {command_id}".format(command_id=command_id))
        except pygenie.exceptions.GenieHTTPError:
            LOGGER.warn("Command: {command} exists. Updating in Genie...".format(command=command["id"]))
            genie.update_command(command)
            command_id = command["id"]                
       
        # set applications for the commands 
        command_application_ids = []
        for application_name in command_mapping['applications']:
            command_application_ids.append(application_ids[application_name])
        try:
            genie.set_application_for_command(command_id, command_application_ids)
            LOGGER.info("Set applications: {applications} for command: {command_id}".format(applications=','.join(command_mapping['applications']), command_id=command_id))
        except Exception:
            LOGGER.info("Applications: {applications} for command: {command_id} already registered".format(applications=','.join(command_mapping['applications']), command_id=command_id))

