#!/usr/bin/python
# Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
# SPDX-License-Identifier: MIT-0
#
# Permission is hereby granted, free of charge, to any person obtaining a copy of this
# software and associated documentation files (the "Software"), to deal in the Software
# without restriction, including without limitation the rights to use, copy, modify,
# merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
# permit persons to whom the Software is furnished to do so.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
# INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
# HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
# OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
# SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
#
import sys
import logging
from pygenie.client import Genie
from pygenie.conf import GenieConf

logging.basicConfig(level=logging.WARNING)
LOGGER = logging.getLogger(__name__)

if __name__ == "__main__":
    (cluster_id, genie_endpoint) = sys.argv[1:]

    genie_conf = GenieConf()
    genie_conf.genie.url = genie_endpoint
    
    genie = Genie(genie_conf)
    try:
        LOGGER.info("Removing commands for cluster {cluster_id}".format(cluster_id=cluster_id))
        genie.remove_all_commands_for_cluster(cluster_id)
     
        LOGGER.info("Removing tags for cluster {cluster_id}".format(cluster_id=cluster_id))
        genie.remove_all_tags_for_cluster(cluster_id)
           
        LOGGER.info("Deleting cluster {cluster_id}".format(cluster_id=cluster_id))
        genie.delete_cluster(cluster_id)
    
        LOGGER.info("Successfully unregistered cluster {cluster_id} and all linked commands and applications.".format(cluster_id=cluster_id))
    except:
        LOGGER.info("Something failed when deleting cluster {cluster_id}".format(cluster_id=cluster_id))
